---
title: <span class="badge object-type-scalar"></span> Hours
---
# <span class="badge object-type-scalar"></span> Hours

Time: hours (h)

## Definition

```python
# Time: hours (h)
Hours: typing.Literal["h"] = "h"
```
